# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from internal_integration_handler_connector.models.send_message_in_group_chat import SendMessageInGroupChat  # noqa: E501

class TestSendMessageInGroupChat(unittest.TestCase):
    """SendMessageInGroupChat unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendMessageInGroupChat:
        """Test SendMessageInGroupChat
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendMessageInGroupChat`
        """
        model = SendMessageInGroupChat()  # noqa: E501
        if include_optional:
            return SendMessageInGroupChat(
                portal_id = 56,
                portal_member = internal_integration_handler_connector.models.portal_member.PortalMember(
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    phone_number = '', 
                    id = 56, 
                    role_id = 56, ),
                message = '',
                chat_id = 56
            )
        else:
            return SendMessageInGroupChat(
                portal_id = 56,
                portal_member = internal_integration_handler_connector.models.portal_member.PortalMember(
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    phone_number = '', 
                    id = 56, 
                    role_id = 56, ),
                message = '',
                chat_id = 56,
        )
        """

    def testSendMessageInGroupChat(self):
        """Test SendMessageInGroupChat"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from internal_integration_handler_connector.models.add_new_stream_recording_to_module import AddNewStreamRecordingToModule  # noqa: E501

class TestAddNewStreamRecordingToModule(unittest.TestCase):
    """AddNewStreamRecordingToModule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AddNewStreamRecordingToModule:
        """Test AddNewStreamRecordingToModule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AddNewStreamRecordingToModule`
        """
        model = AddNewStreamRecordingToModule()  # noqa: E501
        if include_optional:
            return AddNewStreamRecordingToModule(
                portal_id = 56,
                parent_folder_id = 56,
                thumbnail_file_id = '',
                module_id = 56,
                autopublish = True,
                add_to_beginning = True,
                stream_download_url = '',
                stream_download_headers = internal_integration_handler_connector.models.stream_download_headers.Stream Download Headers()
            )
        else:
            return AddNewStreamRecordingToModule(
                portal_id = 56,
                module_id = 56,
                autopublish = True,
                stream_download_url = '',
                stream_download_headers = internal_integration_handler_connector.models.stream_download_headers.Stream Download Headers(),
        )
        """

    def testAddNewStreamRecordingToModule(self):
        """Test AddNewStreamRecordingToModule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from internal_integration_handler_connector.api.internal_integrations_api import InternalIntegrationsApi  # noqa: E501


class TestInternalIntegrationsApi(unittest.IsolatedAsyncioTestCase):
    """InternalIntegrationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = InternalIntegrationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_internal_integrations_add_lesson_from_stream_recording(self) -> None:
        """Test case for internal_integrations_add_lesson_from_stream_recording

        Add Lesson From Stream Recording  # noqa: E501
        """
        pass

    async def test_internal_integrations_add_tags_to_portal_member(self) -> None:
        """Test case for internal_integrations_add_tags_to_portal_member

        Add Tags To Portal Member  # noqa: E501
        """
        pass

    async def test_internal_integrations_add_user_to_group_chat(self) -> None:
        """Test case for internal_integrations_add_user_to_group_chat

        Add User To Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_create_order(self) -> None:
        """Test case for internal_integrations_create_order

        Create Order  # noqa: E501
        """
        pass

    async def test_internal_integrations_remove_tags_from_portal_member(self) -> None:
        """Test case for internal_integrations_remove_tags_from_portal_member

        Remove Tags From Portal Member  # noqa: E501
        """
        pass

    async def test_internal_integrations_remove_user_from_group_chat(self) -> None:
        """Test case for internal_integrations_remove_user_from_group_chat

        Remove User From Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_send_chat_message_to_group_chat(self) -> None:
        """Test case for internal_integrations_send_chat_message_to_group_chat

        Send Chat Message To Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_send_personal_chat_message(self) -> None:
        """Test case for internal_integrations_send_personal_chat_message

        Send Personal Chat Message  # noqa: E501
        """
        pass

    async def test_internal_integrations_validate_message_template(self) -> None:
        """Test case for internal_integrations_validate_message_template

        Validate Message Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
